##  Modeling SaaS Services
SaaS services are modeled as applications since they process data and help organizations complete business tasks. Use the reference catalog to automatically add descriptions and other essential details, as well as to automatically create related IT components and providers. For more details, see [Applications in the Reference Catalog](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for application fact sheets, you can increase standardization and data quality, as well as set relations to other fact sheets for best-practice modeling.").
If your organization has a significant number of SaaS services, leverage the SaaS discovery feature. It pulls your most important SaaS services into your workspace through your Single-Sign-On (SSO), Secure Access Simplified (SASE), and Cloud Access Security Broker (CASB) solutions. You can automatically create relevant fact sheets for discovered services or link them to existing fact sheets to update information automatically. These application fact sheets are also linked to the reference catalog, ensuring regular updates and allowing you to create or update associated IT components and providers. For more details, see [SaaS Discovery](https://help.sap.com/docs/leanix/ea/saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "SaaS discovery identifies your organization's SaaS applications by integrating with SSO, SASE, and CASB solutions. It then updates and enriches fact sheets using the reference catalog.").
For an illustrated example of how to model a SaaS application, see [Complete Modeling Example – SAP LeanIX as an Application](https://help.sap.com/docs/leanix/ea/general-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a3a157a441014a44fe44b7fc123f5__complete_modeling_example_sap_leanix_as_an_application).
**Note**
ERPs (e.g., SAP S/4HANA) and other large systems like Salesforce are more complex and are explained in dedicated modeling guides. To learn how to model them, see [Modeling Best Practices](https://help.sap.com/docs/leanix/ea/modeling-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD "Best practices for modeling major IT systems.").
**Tip**
Modeling IT components and providers requires minimal effort when using the reference catalog and SaaS discovery feature. Even if not immediately needed, having them in your inventory is valuable for managing more complex setups. For example, you might have a self-hosted application where the server provider differs from the hosting provider or a SaaS application that relies on an SSO IT component.
Modeling IT components and providers gives you clear visibility into hosting, helps generate important reports like the provider cost report, and offers essential data for better risk management.
